==> kde-wallpaper-cli-1.0.0.tar.gz: kde-wallpaper-cli-1.0.0/README.md <==
# kde-wallpaper-cli
**@readwithai** - [X](https://x.com/readwithai) - [blog](https://readwithai.substack.com/) - [machine-aided reading](https://www.reddit.com/r/machineAidedReading/) - [📖](https://readwithai.substack.com/p/what-is-reading-broadly-defined
)[⚡️](https://readwithai.substack.com/s/technical-miscellany)[🖋️](https://readwithai.substack.com/p/note-taking-with-obsidian-much-of)

Set the wallpaper for KDE from the command-line.

## Attribution
The approach used here was [documented on stackoverflow](https://superuser.com/questions/488232/how-to-set-kde-desktop-wallpaper-from-command-line) and [this blogpost](https://www.gkbrk.com/change-kde-wallpaper-from-the-command-line) by Yaltirakli, which uses the same motivation.

## Motivation
It's so silly. It should be easy to set the wallpaper from the command-line. Also, I like to have as little of "my own" configuration as possible and instead push this into open source command-line tools so moving machines is useful.

Instead, the ["accepted" way of doing this](https://superuser.com/questions/488232/how-to-set-kde-desktop-wallpaper-from-command-line) seems to be send a script to KDE's plasmashell to update the wallpaper for each desktop.

## Alternatives and prior work
I tried [superpaper](https://github.com/hhannine/superpaper) but this did not work with [pipx](https://github.com/hhannine/superpaper/issues/142) without manual tweaks.

Tools like feh can set wallpaper for other window managers.

## Related tools
You might like to try my program [mapillary-nearby](https://github.com/talwrii/mapillary-nearby) which will find streetview style images around a given area.

## About me
I am **@readwithai**. I create tools for reading, research and agency sometimes using the markdown editor [Obsidian](https://readwithai.substack.com/p/what-exactly-is-obsidian).

I also create a [stream of tools](https://readwithai.substack.com/p/my-productivity-tools) that are related to carrying out my work.

I write about lots of things - including tools like this - on [X](https://x.com/readwithai).
My [blog](https://readwithai.substack.com/) is more about reading and research and agency.

==> kde-wallpaper-cli-1.1.0.tar.gz: kde-wallpaper-cli-1.1.0/README.md <==
# kde-wallpaper-cli
**@readwithai** - [X](https://x.com/readwithai) - [blog](https://readwithai.substack.com/) - [machine-aided reading](https://www.reddit.com/r/machineAidedReading/) - [📖](https://readwithai.substack.com/p/what-is-reading-broadly-defined
)[⚡️](https://readwithai.substack.com/s/technical-miscellany)[🖋️](https://readwithai.substack.com/p/note-taking-with-obsidian-much-of)

Set the wallpaper for KDE from the command-line.

## Attribution
The approach used here was [documented on stackoverflow](https://superuser.com/questions/488232/how-to-set-kde-desktop-wallpaper-from-command-line) and [this blogpost](https://www.gkbrk.com/change-kde-wallpaper-from-the-command-line) by Yaltirakli, which uses the same motivation.

## Motivation
It's so silly. It should be easy to set the wallpaper from the command-line. But in KDE there is no easy way to do this, instead you have to send a dbus message which runs a script which configures the desktop. I'm not going to remember this, and so I'd need to put this in a script. Also, I like to have as little of "my own" configuration as possible and instead push this into open source command-line tools so moving machines is useful. This creates this script, but makes it easy to install this on a new machine and shares this with the world.

The ["accepted" way of doing this](https://superuser.com/questions/488232/how-to-set-kde-desktop-wallpaper-from-command-line) seems to be send a script to KDE's plasmashell to update the wallpaper for each desktop.

## Alternatives and prior work
I tried [superpaper](https://github.com/hhannine/superpaper) but this did not work with [pipx](https://github.com/hhannine/superpaper/issues/142) without manual tweaks.

Tools like feh can set wallpaper for other window managers.

## Related tools
You might like to try my program [mapillary-nearby](https://github.com/talwrii/mapillary-nearby) which will find streetview style images around a given area.

## About me
I am **@readwithai**. I create tools for reading, research and agency sometimes using the markdown editor [Obsidian](https://readwithai.substack.com/p/what-exactly-is-obsidian).

I also create a [stream of tools](https://readwithai.substack.com/p/my-productivity-tools) that are related to carrying out my work.

I write about lots of things - including tools like this - on [X](https://x.com/readwithai).
My [blog](https://readwithai.substack.com/) is more about reading and research and agency.

[![@readwithai logo](./logo.png)](https://readwithai.substack.com/)
